core

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 13, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(ctx context.Context, addr string, key string) string

Get invokes Kevlar Get Key API and returns a printable output for the CLI.

func Set

func Set(ctx context.Context, addr string, key string, value string) string

Set invokes Kevlar Set Key API and returns a printable output for the CLI.

Types

This section is empty.

Jump to